@@ -1,6 +1,6 @@
 package Twitter::API::Role::RequestArgs;
 # ABSTRACT: API request method helpers
-$Twitter::API::Role::RequestArgs::VERSION = '0.0110';
+$Twitter::API::Role::RequestArgs::VERSION = '0.0111';
 use 5.14.1;
 use warnings;
 use Carp;
@@ -102,6 +102,24 @@ sub request_with_id {
 #pod =cut
 
 sub request_with_pos_args {
+    my $self = shift;
+
+    $self->request($self->normalize_pos_args(@_));
+}
+
+#pod =method normalize_pos_args
+#pod
+#pod Helper method for C<request_with_pos_args>. Takes the same arguments described in
+#pod C<request_with_pos_args> above, and returns a list of arguments ready for a
+#pod call to C<request>.
+#pod
+#pod Individual methods in L<Twitter::API::Trait::ApiMethods> use
+#pod C<normalize_pos_args> if they need to do further processing on the args hashref
+#pod before calling C<request>.
+#pod
+#pod =cut
+
+sub normalize_pos_args {
     my $self        = shift;
     my @pos_names   = shift;
     my $http_method = shift;
@@ -143,7 +161,26 @@ sub request_with_pos_args {
         $args{$name} = $args_hash{$name};
     }
 
-    $self->request($http_method, $path, \%args, @_);
+    return ($http_method, $path, \%args, @_);
+}
+
+#pod =method flatten_list_args([ $key | \@keys ], \%args)
+#pod
+#pod Some Twitter API arguments take a list of values as a string of comma separated
+#pod items. To allow callers to pass an array reference of items instead, this
+#pod method is used to flatten array references to strings. The key or keys identify
+#pod which values to flatten in the C<\%args> hash reference, if they exist.
+#pod
+#pod =cut
+
+sub flatten_list_args {
+    my ( $self, $keys, $args ) = @_;
+
+    for my $key ( is_arrayref($keys) ? @$keys : $keys ) {
+        if ( my $value = $args->{$key} ) {
+            $args->{$key} = join ',' => @$value if is_arrayref($value);
+        }
+    }
 }
 
 1;
@@ -160,7 +197,7 @@ Twitter::API::Role::RequestArgs - API request method helpers
 
 =head1 VERSION
 
-version 0.0110
+version 0.0111
 
 =head1 SYNOPSIS
 
@@ -274,6 +311,23 @@ Examples:
         status     => 'down the rabbit hole',
     });
 
+=head2 normalize_pos_args
+
+Helper method for C<request_with_pos_args>. Takes the same arguments described in
+C<request_with_pos_args> above, and returns a list of arguments ready for a
+call to C<request>.
+
+Individual methods in L<Twitter::API::Trait::ApiMethods> use
+C<normalize_pos_args> if they need to do further processing on the args hashref
+before calling C<request>.
+
+=head2 flatten_list_args([ $key | \@keys ], \%args)
+
+Some Twitter API arguments take a list of values as a string of comma separated
+items. To allow callers to pass an array reference of items instead, this
+method is used to flatten array references to strings. The key or keys identify
+which values to flatten in the C<\%args> hash reference, if they exist.
+
 =head1 AUTHOR
 
 Marc Mims <marc@questright.com>
